# SatIOpsT: Satellite Image Operations Toolbox
This package helps you to run various oparations on satellite images. Currently Under development.

### Installation Process:
You need anaconda or miniconda to run this package. First install anaconda or miniconda in your PC, From anaconda navigator or anaconda terminal run:

    conda install gdal rasterio geopandas pandas numpy scipy
    # After finish this installation install this package.
    pip install SatIOpsT

### Change log:

#### -0.0.3
        -managed some errors.
#### -0.0.4
	-Fixed some bugs.
	-Added Reprojection.
#### -0.0.6
        -Added time series conversions for Raster data.
#### -0.0.7
		-Minor correction.
### Help Page:
https://github.com/SubhadipDatta/SatIOpsT/wiki
